Learn R Programming

gfilinreg (version 2.0.1)

MAXLHD: Maximum likelihood estimates of simulations

Description

A matrix containing the maximum likelihood estimates of the simulations whose code is given in the vignette.

Usage

MAXLHD

Arguments

Format

A matrix with 500 rows and 3 columns.