Learn R Programming

gfilinreg (version 2.0.1)

gfiQuantile: Fiducial quantiles

Description

Quantiles of the fiducial distribution of a parameter of interest.

Usage

gfiQuantile(parameter, fidsamples, probs)

Arguments

parameter

a right-sided formula defining the parameter of interest

fidsamples

fiducial samples, the output of gfilinreg or gfilinregPredictive

probs

numeric vector of probabilities

Value

Numeric vector of quantiles, of the same length as probs.

Examples

Run this code
# NOT RUN {
set.seed(666L)
dat <- data.frame(
  group = gl(2, 15), 
  y = c(2*rlogis(15L), 10 + 2*rlogis(15L))
)
gfi <- gfilinreg(
  y ~ 0 + group, distr = "logistic", data = dat, L = 30L, nthreads = 2L
)
gfiQuantile(~ group1 - group2, gfi, c(25, 50, 75)/100)
# }

Run the code above in your browser using DataLab